@@ -43,7 +43,7 @@ class ErrorInfo(Error):
     name = "no-with-assign"
     code = 127
     msg: str = "This variable is redeclared later, and can be removed here"
-    categories = ["readability", "scoping"]
+    categories = ("readability", "scoping")
 
 
 def check(node: Block | MypyFile, errors: list[Error]) -> None:
