@@ -5,10 +5,13 @@ from mypy.nodes import (
     Argument,
     Block,
     CallExpr,
+    DictExpr,
     Expression,
     LambdaExpr,
+    ListExpr,
     NameExpr,
     ReturnStmt,
+    TupleExpr,
 )
 
 from refurb.error import Error
@@ -39,7 +42,7 @@ class ErrorInfo(Error):
 
     name = "use-func-name"
     code = 111
-    categories = ["readability"]
+    categories = ("readability",)
 
 
 def get_lambda_arg_names(args: list[Argument]) -> list[str]:
@@ -76,3 +79,32 @@ def check(node: LambdaExpr, errors: list[Error]) -> None:
                     f"Replace `{_lambda}: {func_name}({arg_names})` with `{func_name}`",  # noqa: E501
                 )
             )
+
+        case LambdaExpr(
+            arguments=[],
+            body=Block(
+                body=[
+                    ReturnStmt(
+                        expr=ListExpr(items=[])
+                        | DictExpr(items=[])
+                        | TupleExpr(items=[]) as expr,
+                    )
+                ],
+            ),
+        ):
+            if isinstance(expr, ListExpr):
+                old = "[]"
+                new = "list"
+            elif isinstance(expr, DictExpr):
+                old = "{}"
+                new = "dict"
+            else:
+                old = "()"
+                new = "tuple"
+
+            errors.append(
+                ErrorInfo.from_node(
+                    node,
+                    f"Replace `lambda: {old}` with `{new}`",
+                )
+            )
